@@ -37,7 +37,7 @@ class FileManagerReadOnly(FileManagerData, Mapping):
         KeyError
             If there is no object associated with the given key.
         """
-        engine_key = self.key_mapping.get_engine_key_from_dict(key)
+        engine_key = self._get_engine_key(key)
         result = self.engine.get_item(engine_key)
         for transformation in self.transformation_list:
             result = transformation.convert_from_engine_to_dict(result)
@@ -45,9 +45,19 @@ class FileManagerReadOnly(FileManagerData, Mapping):
 
     def __iter__(self) -> Iterator[Any]:
         """Yield the keys found in the bucket."""
-        for engine_key in self.engine.list_keys():
-            yield self.key_mapping.get_dict_key_from_engine(engine_key)
+        for key in self.engine.list_keys():
+            yield self._get_dict_key(key)
 
     def __len__(self) -> int:
         """Count the number of keys found in the work folder."""
         return sum(1 for _ in self)
+
+    def _get_engine_key(self, dict_key: Any) -> Any:
+        return self.engine.convert_to_absolute_path(
+            self.key_mapping.get_engine_key_from_dict(dict_key)
+        )
+
+    def _get_dict_key(self, engine_key: Any) -> Any:
+        return self.key_mapping.get_dict_key_from_engine(
+            self.engine.convert_to_relative_path(engine_key)
+        )
